#[repr(i32)]pub enum ActorType {
Unspecified = 0,
User = 1,
Agent = 2,
System = 3,
External = 4,
}Expand description
ActorType classifies actors.
Variants
Unspecified = 0
User = 1
Human user (via mobile app, CLI, etc.)
Agent = 2
AI agent or automated process.
System = 3
System component (scheduler, garbage collector, etc.)
External = 4
External service (webhook, payment provider, etc.)
Implementations
Sourceimpl ActorType
impl ActorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.