#[repr(i32)]pub enum RunStatus {
Unspecified = 0,
Pending = 1,
Running = 2,
Converged = 3,
Halted = 4,
Waiting = 5,
Cancelled = 6,
}Expand description
RunStatus represents the lifecycle state of a convergence run.
Variants
Unspecified = 0
Pending = 1
Not yet started.
Running = 2
Truths firing, facts arriving.
Converged = 3
Stable state reached, no more truths to fire.
Halted = 4
Invariant violated, explanation available.
Waiting = 5
Blocked on external input (human approval, etc.)
Cancelled = 6
User cancelled.
Implementations
Sourceimpl RunStatus
impl RunStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.