pub struct GetCapabilitiesResponse {
pub packs: Vec<PackInfo>,
pub active_truths: Vec<TruthInfo>,
pub streaming: Option<StreamingCapabilities>,
pub determinism_mode_available: bool,
pub server_version: String,
pub server_time_ns: u64,
}Expand description
GetCapabilitiesResponse returns available features and packs.
Fields
packs: Vec<PackInfo>Available packs.
active_truths: Vec<TruthInfo>Active truths.
streaming: Option<StreamingCapabilities>Streaming capabilities.
determinism_mode_available: boolFeature flags.
server_version: StringServer info.
server_time_ns: u64Trait Implementations
Sourceimpl Clone for GetCapabilitiesResponse
impl Clone for GetCapabilitiesResponse
Sourcefn clone(&self) -> GetCapabilitiesResponse
fn clone(&self) -> GetCapabilitiesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetCapabilitiesResponse
impl Debug for GetCapabilitiesResponse
Sourceimpl Default for GetCapabilitiesResponse
impl Default for GetCapabilitiesResponse
Sourceimpl Message for GetCapabilitiesResponse
impl Message for GetCapabilitiesResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetCapabilitiesResponse
impl PartialEq for GetCapabilitiesResponse
Sourcefn eq(&self, other: &GetCapabilitiesResponse) -> bool
fn eq(&self, other: &GetCapabilitiesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetCapabilitiesResponse