pub struct RunStatusChanged {
pub run_id: String,
pub job_id: String,
pub status: i32,
pub previous_status: i32,
pub halt_info: Option<HaltInfo>,
pub waiting_info: Option<WaitingInfo>,
pub converged_info: Option<ConvergedInfo>,
pub facts_count: u32,
pub pending_proposals: u32,
pub cycles_completed: u32,
}Expand description
RunStatusChanged is emitted when a run’s status changes.
Fields
run_id: Stringjob_id: Stringstatus: i32New status.
previous_status: i32Previous status.
halt_info: Option<HaltInfo>Details for specific states.
When halted
waiting_info: Option<WaitingInfo>When waiting
converged_info: Option<ConvergedInfo>When converged
facts_count: u32Current stats.
pending_proposals: u32cycles_completed: u32Implementations
Sourceimpl RunStatusChanged
impl RunStatusChanged
Sourcepub fn status(&self) -> RunStatus
pub fn status(&self) -> RunStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: RunStatus)
pub fn set_status(&mut self, value: RunStatus)
Sets status to the provided enum value.
Sourcepub fn previous_status(&self) -> RunStatus
pub fn previous_status(&self) -> RunStatus
Returns the enum value of previous_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_previous_status(&mut self, value: RunStatus)
pub fn set_previous_status(&mut self, value: RunStatus)
Sets previous_status to the provided enum value.