pub struct SubscribeRequest {
pub job_id: Option<String>,
pub run_id: Option<String>,
pub correlation_id: Option<String>,
pub since_sequence: u64,
pub entry_types: Vec<i32>,
}Expand description
SubscribeRequest subscribes to events for a job, run, or correlation.
Fields
job_id: Option<String>What to subscribe to (at least one required).
run_id: Option<String>correlation_id: Option<String>since_sequence: u64Resume from sequence (0 = from now, omit for all history).
entry_types: Vec<i32>Filter by entry types (empty = all).
Implementations
Sourceimpl SubscribeRequest
impl SubscribeRequest
Sourcepub fn job_id(&self) -> &str
pub fn job_id(&self) -> &str
Returns the value of job_id, or the default value if job_id is unset.
Sourcepub fn run_id(&self) -> &str
pub fn run_id(&self) -> &str
Returns the value of run_id, or the default value if run_id is unset.
Sourcepub fn correlation_id(&self) -> &str
pub fn correlation_id(&self) -> &str
Returns the value of correlation_id, or the default value if correlation_id is unset.
Sourcepub fn entry_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<EntryType>>
pub fn entry_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<EntryType>>
Returns an iterator which yields the valid enum values contained in entry_types.
Sourcepub fn push_entry_types(&mut self, value: EntryType)
pub fn push_entry_types(&mut self, value: EntryType)
Appends the provided enum value to entry_types.